Struct diem_sdk::crypto::x25519::x25519_dalek::EphemeralSecret [−][src]
pub struct EphemeralSecret(_);Expand description
A short-lived Diffie-Hellman secret key that can only be used to compute a single
SharedSecret.
This type is identical to the StaticSecret type, except that the
EphemeralSecret::diffie_hellman method consumes and then wipes the secret key, and there
are no serialization methods defined. This means that EphemeralSecrets can only be
generated from fresh randomness by EphemeralSecret::new and the compiler statically checks
that the resulting secret is used at most once.
Implementations
Perform a Diffie-Hellman key agreement between self and
their_public key to produce a SharedSecret.
Generate an x25519 EphemeralSecret key.